"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 7948899b3068

from __future__ import annotations
from .connectorcalltoolrequest import (
    ConnectorCallToolRequest,
    ConnectorCallToolRequestTypedDict,
)
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class ConnectorCallToolV1RequestTypedDict(TypedDict):
    tool_name: str
    connector_id_or_name: str
    connector_call_tool_request: ConnectorCallToolRequestTypedDict


class ConnectorCallToolV1Request(BaseModel):
    tool_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    connector_id_or_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    connector_call_tool_request: Annotated[
        ConnectorCallToolRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
