"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .contentchunk import ContentChunk, ContentChunkTypedDict
from .toolcall import ToolCall, ToolCallTypedDict
from mistralai.gcp.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


DeltaMessageContentTypedDict = TypeAliasType(
    "DeltaMessageContentTypedDict", Union[str, List[ContentChunkTypedDict]]
)


DeltaMessageContent = TypeAliasType(
    "DeltaMessageContent", Union[str, List[ContentChunk]]
)


class DeltaMessageTypedDict(TypedDict):
    role: NotRequired[Nullable[str]]
    content: NotRequired[Nullable[DeltaMessageContentTypedDict]]
    tool_calls: NotRequired[Nullable[List[ToolCallTypedDict]]]


class DeltaMessage(BaseModel):
    role: OptionalNullable[str] = UNSET

    content: OptionalNullable[DeltaMessageContent] = UNSET

    tool_calls: OptionalNullable[List[ToolCall]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["role", "content", "tool_calls"])
        nullable_fields = set(["role", "content", "tool_calls"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
