"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3b9fc81aa726

from __future__ import annotations
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import FieldMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ConnectorsQueryFiltersTypedDict(TypedDict):
    active: NotRequired[Nullable[bool]]
    r"""Filter for active connectors for a given user, workspace and organization."""
    fetch_connection_secrets: NotRequired[bool]
    r"""Fetch connection secrets."""


class ConnectorsQueryFilters(BaseModel):
    active: Annotated[OptionalNullable[bool], FieldMetadata(query=True)] = UNSET
    r"""Filter for active connectors for a given user, workspace and organization."""

    fetch_connection_secrets: Annotated[Optional[bool], FieldMetadata(query=True)] = (
        False
    )
    r"""Fetch connection secrets."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["active", "fetch_connection_secrets"])
        nullable_fields = set(["active"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
